@@ -14,12 +14,10 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import json
-from urllib import urlencode
-import urlparse
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.paginator import Paginator, EmptyPage
+import yajl as json
 from eggplant.utils.url import replace_querystring
 from eggplant.validators.number import range_validator
 from eggplant.validators.string import is_integer, is_positive_integer
@@ -106,7 +104,20 @@ class ModelCollectionView(ModelViewBase):
             if len(orders):
                 query_set = self.order(query_set, orders, *args, **kwargs)
 
-        # TODO: filter
+        # Filter
+#        raw_filter = self.request.GET.get('filter', None)
+#        if raw_filter:
+#            try: filters = json.loads(raw_filter)
+#            except ValueError: filters = []
+#        else: filters = []
+#        for filter in filters:
+#            try:
+#                key, operator, value = filter
+#                # TODO: do filter
+#            except ValueError:
+#                e = exceptions.BadRequestError('Invalid filter format')
+#                e.user_info = {'raw_filter': filter}
+#                raise e
 
         meta_info = {}
         # Pagination
@@ -193,9 +204,9 @@ class ModelCollectionView(ModelViewBase):
             }
         else:
             result = collection
-            self.response['X-Meta'] = json.dumps(meta_info, separators=(',',':'))
+            self.response['X-Meta'] = json.dumps(meta_info)
 
-        self.response.content = json.dumps(result, separators=(',',':'))
+        self.response.content = json.dumps(result)
 
     def post(self, *args, **kwargs):
         new_model = self.create_model(self.MODEL_COLLECTION_CLASS, *args, **kwargs)
